import { createHighlighterCore } from '@shikijs/core';
import { createJavaScriptRegexEngine } from '@shikijs/engine-javascript';

var __async = (__this, __arguments, generator) => {
  return new Promise((resolve, reject) => {
    var fulfilled = (value) => {
      try {
        step(generator.next(value));
      } catch (e) {
        reject(e);
      }
    };
    var rejected = (value) => {
      try {
        step(generator.throw(value));
      } catch (e) {
        reject(e);
      }
    };
    var step = (x) => x.done ? resolve(x.value) : Promise.resolve(x.value).then(fulfilled, rejected);
    step((generator = generator.apply(__this, __arguments)).next());
  });
};
function log(message, ...args) {
  {
    console.log(`[ShikiContext] ${message}`, ...args);
  }
}
let highlighterInstance = null;
function getHighlighter() {
  return __async(this, null, function* () {
    if (highlighterInstance) {
      log("Returning cached highlighter instance");
      return highlighterInstance;
    }
    try {
      log("Creating new highlighter instance...");
      log("Initializing JavaScript regex engine...");
      const engine = createJavaScriptRegexEngine({
        forgiving: true,
        simulation: true,
        cache: /* @__PURE__ */ new Map()
      });
      log("Engine created successfully");
      log("Loading required languages...");
      log("Languages loaded successfully");
      log("Creating highlighter core...");
      highlighterInstance = yield createHighlighterCore({
        engine
      });
      log("Highlighter core created successfully");
      log("Highlighter initialization complete");
      return highlighterInstance;
    } catch (err) {
      log("Highlighter initialization failed:", err);
      throw err;
    }
  });
}

export { getHighlighter };
//# sourceMappingURL=SyntaxContext.js.map
